@@ -21,7 +21,9 @@ from numpy import (absolute,
                    median,
                    mean,
                    nan,
+                   nanmax,
                    nanmean,
+                   nanmin,
                    nanstd,
                    negative,
                    ones,
